@@ -14,7 +14,7 @@
 #define BAR_EXIF_H
 
 
-GtkWidget *bar_exif_new(gint show_title, const gchar *path, gint advanced);
+GtkWidget *bar_exif_new(gint show_title, const gchar *path, gint advanced, GtkWidget *bounding_widget);
 void bar_exif_close(GtkWidget *bar);
 
 void bar_exif_set(GtkWidget *bar, const gchar *path);
