@@ -17,10 +17,22 @@
 #include "similar.h"
 
 
-#define GQVIEW_CACHE_DIR ".thumbnails"
-#define GQVIEW_CACHE_THUMB_EXT ".png"
-#define GQVIEW_CACHE_SIMIL_EXT ".sim"
+#define GQVIEW_CACHE_RC_THUMB       GQVIEW_RC_DIR"/thumbnails"
+#define GQVIEW_CACHE_RC_METADATA    GQVIEW_RC_DIR"/metadata"
 
+#define GQVIEW_CACHE_LOCAL_THUMB    ".thumbnails"
+#define GQVIEW_CACHE_LOCAL_METADATA ".metadata"
+
+#define GQVIEW_CACHE_EXT_THUMB      ".png"
+#define GQVIEW_CACHE_EXT_SIM        ".sim"
+#define GQVIEW_CACHE_EXT_METADATA   ".meta"
+
+
+typedef enum {
+	CACHE_TYPE_THUMB,
+	CACHE_TYPE_SIM,
+	CACHE_TYPE_METADATA
+} CacheType;
 
 typedef struct _CacheData CacheData;
 struct _CacheData
@@ -29,13 +41,17 @@ struct _CacheData
 	gint width;
 	gint height;
 	long checksum;
+	guchar md5sum[16];
 	ImageSimilarityData *sim;
 
 	gint dimensions;
 	gint have_checksum;
+	gint have_md5sum;
 	gint similarity;
 };
 
+gint cache_time_valid(const gchar *cache, const gchar *path);
+
 
 CacheData *cache_sim_data_new(void);
 void cache_sim_data_free(CacheData *cd);
@@ -45,15 +61,14 @@ CacheData *cache_sim_data_load(const gchar *path);
 
 void cache_sim_data_set_dimensions(CacheData *cd, gint w, gint h);
 void cache_sim_data_set_checksum(CacheData *cd, long checksum);
+void cache_sim_data_set_md5sum(CacheData *cd, guchar digest[16]);
 void cache_sim_data_set_similarity(CacheData *cd, ImageSimilarityData *sd);
 gint cache_sim_data_filled(ImageSimilarityData *sd);
 
 
 gint cache_ensure_dir_exists(gchar *path, mode_t mode);
-gchar *cache_get_location(const gchar *source, gint include_name, const gchar *ext, mode_t *mode);
-gchar *cache_find_location(const gchar *source, const gchar *ext);
-
-gint cache_time_valid(const gchar *cache, const gchar *path);
+gchar *cache_get_location(CacheType type, const gchar *source, gint include_name, mode_t *mode);
+gchar *cache_find_location(CacheType type, const gchar *source);
 
 
 #endif
