@@ -56,7 +56,7 @@ static gint collection_save_confirmed(FileDialog *fd, gint overwrite, Collection
 	if (isdir(fd->dest_path))
 		{
 		buf = g_strdup_printf(_("Specified path:\n%s\nis a folder, collections are files"), fd->dest_path);
-		file_util_warning_dialog(_("Invalid filename"), buf, GENERIC_DIALOG(fd)->dialog);
+		file_util_warning_dialog(_("Invalid filename"), buf, GTK_STOCK_DIALOG_INFO, GENERIC_DIALOG(fd)->dialog);
 		g_free(buf);
 		return FALSE;
 		}
@@ -65,13 +65,14 @@ static gint collection_save_confirmed(FileDialog *fd, gint overwrite, Collection
 		{
 		GenericDialog *gd;
 
-		buf = g_strdup_printf(_("Overwrite collection file:\n%s"), fd->dest_path);
-		gd = file_util_gen_dlg(_("Overwrite File"), buf, "GQview", "dlg_confirm",
+		gd = file_util_gen_dlg(_("Overwrite File"), "GQview", "dlg_confirm",
 					GENERIC_DIALOG(fd)->dialog, TRUE,
 					collection_confirm_cancel_cb, fd);
-		g_free(buf);
 
-		generic_dialog_add_stock(gd, _("Overwrite"), GTK_STOCK_OK, collection_confirm_ok_cb, TRUE);
+		generic_dialog_add_message(gd, GTK_STOCK_DIALOG_QUESTION,
+					   _("Overwrite existing file?"), fd->dest_path);
+
+		generic_dialog_add_button(gd, GTK_STOCK_OK, _("_Overwrite"), collection_confirm_ok_cb, TRUE);
 
 		gtk_widget_show(gd->dialog);
 
@@ -81,7 +82,7 @@ static gint collection_save_confirmed(FileDialog *fd, gint overwrite, Collection
 	if (!collection_save(cd, fd->dest_path))
 		{
 		buf = g_strdup_printf(_("Failed to save the collection:\n%s"), fd->dest_path);
-		file_util_warning_dialog(_("Save Failed"), buf, GENERIC_DIALOG(fd)->dialog);
+		file_util_warning_dialog(_("Save Failed"), buf, GTK_STOCK_DIALOG_ERROR, GENERIC_DIALOG(fd)->dialog);
 		g_free(buf);
 		}
 
@@ -156,9 +157,8 @@ static void collection_save_or_load_dialog(const gchar *path,
 	FileDialog *fd;
 	GtkWidget *parent = NULL;
 	CollectWindow *cw;
-	gchar *title;
-	gchar *text;
-	gchar *btntext;
+	const gchar *title;
+	const gchar *btntext;
 	void *btnfunc;
 	gchar *base;
 	const gchar *stock_id;
@@ -167,16 +167,14 @@ static void collection_save_or_load_dialog(const gchar *path,
 		{
 		if (!cd) return;
 		title = _("Save collection");
-		text = _("Save collection as:");
-		btntext = _("Save");
+		btntext = NULL;
 		btnfunc = collection_save_cb;
 		stock_id = GTK_STOCK_SAVE;
 		}
 	else if (type == DIALOG_LOAD)
 		{
 		title = _("Open collection");
-		text = _("Open collection from:");
-		btntext = _("Open");
+		btntext = NULL;
 		btnfunc = collection_load_cb;
 		stock_id = GTK_STOCK_OPEN;
 		}
@@ -184,8 +182,7 @@ static void collection_save_or_load_dialog(const gchar *path,
 		{
 		if (!cd) return;
 		title = _("Append collection");
-		text = _("Append collection from:");
-		btntext = _("Append");
+		btntext = _("_Append");
 		btnfunc = collection_append_cb;
 		stock_id = GTK_STOCK_ADD;
 		}
@@ -195,9 +192,11 @@ static void collection_save_or_load_dialog(const gchar *path,
 	cw = collection_window_find(cd);
 	if (cw) parent = cw->window;
 
-	fd = file_util_file_dlg(title, text, "GQview", "dlg_collection", parent,
+	fd = file_util_file_dlg(title, "GQview", "dlg_collection", parent,
 			     collection_save_or_load_dialog_close_cb, cd);
-	file_dialog_add_button_stock(fd, btntext, stock_id, btnfunc, TRUE);
+
+	generic_dialog_add_message(GENERIC_DIALOG(fd), NULL, title, NULL);
+	file_dialog_add_button(fd, stock_id, btntext, btnfunc, TRUE);
 
 	base = g_strconcat(homedir(), "/", GQVIEW_RC_DIR_COLLECTIONS, NULL);
 	file_dialog_add_path_widgets(fd, base, path,
@@ -211,6 +210,7 @@ static void collection_save_or_load_dialog(const gchar *path,
 
 void collection_dialog_save_as(gchar *path, CollectionData *cd)
 {
+#if 0
 	if (!cd->list)
 		{
 		GtkWidget *parent = NULL;
@@ -219,9 +219,11 @@ void collection_dialog_save_as(gchar *path, CollectionData *cd)
 		cw = collection_window_find(cd);
 		if (cw) parent = cw->window;
 		file_util_warning_dialog(_("Collection empty"),
-					 _("The current collection is empty, save aborted."), parent);
+					 _("The current collection is empty, save aborted."),
+					 GTK_STOCK_DIALOG_INFO, parent);
 		return;
 		}
+#endif
 
 	if (!path) path = cd->path;
 	if (!path) path = cd->name;
