@@ -1,6 +1,6 @@
 /*
  * GQview
- * (C) 2002 John Ellis
+ * (C) 2004 John Ellis
  *
  * Author: John Ellis
  *
@@ -28,11 +28,8 @@ extern GtkTargetEntry dnd_file_drop_types[];
 extern gint dnd_file_drop_types_count;
 
 
-GList *get_uri_file_list(gchar *data);
-gchar *make_uri_file_list(GList *list, gint plain_text, gint *length);
-
-void image_dnd_init(ImageWindow *imd);
-void init_dnd(void);
+/* sets a drag icon to pixbuf, if items is > 1, text is drawn onto icon to indicate value */
+void dnd_set_drag_icon(GtkWidget *widget, GdkDragContext *context, GdkPixbuf *pixbuf, gint items);
 
 
 #endif
