@@ -11,12 +11,6 @@
 
 
 #include "gqview.h"
-#include "globals.h"
-
-#include "icons_inline.h"
-
-#include "logo.xpm"
-#include "icons/img_unknown.xpm"
 
 
 GList *filename_filter = NULL;
@@ -58,11 +52,13 @@ gint fit_window = FALSE;
 gint limit_window_size = FALSE;
 gint zoom_to_fit_expands = TRUE;
 gint max_window_size = 100;
-gint thumb_max_width = 64;
-gint thumb_max_height = 64;
+gint thumb_max_width = 96;
+gint thumb_max_height = 72;
 gint enable_thumb_caching = TRUE;
 gint enable_thumb_dirs = FALSE;
 gint use_xvpics_thumbnails = TRUE;
+gint thumbnail_spec_standard = TRUE;
+gint enable_metadata_dirs = FALSE;
 gint show_dot_files = FALSE;
 gint file_filter_disable = FALSE;
 gchar *editor_name[GQVIEW_EDITOR_SLOTS];
@@ -96,19 +92,15 @@ gint place_dialogs_under_mouse = FALSE;
 
 gint black_window_background = FALSE;
 
-gint fullscreen_screen = 1;
+gint fullscreen_screen = -1;
 gint fullscreen_clean_flip = FALSE;
 gint fullscreen_disable_saver = TRUE;
+gint fullscreen_above = FALSE;
 
 gint dupe_custom_threshold = 99;
 
 gint debug = FALSE;
 
-/* logo & misc images */
-
-const char **logo = (const char **)logo_xpm;
-const char **img_unknown = (const char **)img_unknown_xpm;
-
 /* layout */
 gchar *layout_order = NULL;
 gint layout_style = 0;
