@@ -203,7 +203,7 @@ extern gint exif_rotate_enable;
  * This also doubles as the main.c header.
  */
 
-void window_set_icon(GtkWidget *window, const char **icon, const gchar *file);
+void window_set_icon(GtkWidget *window, const gchar *icon, const gchar *file);
 gint window_maximized(GtkWidget *window);
 
 gdouble get_zoom_increment(void);
