@@ -169,9 +169,6 @@ static GtkWidget *layout_tool_setup(LayoutWindow *lw)
 	GtkWidget *box;
 	GtkWidget *menu_bar;
 	GtkWidget *tabcomp;
-#if 0
-	GtkWidget *popwin;
-#endif
 
 	box = gtk_vbox_new(FALSE, 0);
 
@@ -189,9 +186,6 @@ static GtkWidget *layout_tool_setup(LayoutWindow *lw)
 	gtk_box_pack_start(GTK_BOX(box), tabcomp, FALSE, FALSE, 0);
 	gtk_widget_show(tabcomp);
 
-#if 0
-	popwin = gtk_widget_get_toplevel(GTK_COMBO(tabcomp)->list);
-#endif
 	g_signal_connect(G_OBJECT(lw->path_entry->parent), "changed",
 			 G_CALLBACK(layout_path_entry_changed_cb), lw);
 
@@ -231,6 +225,8 @@ static void layout_sort_menu_cb(GtkWidget *widget, gpointer data)
 	LayoutWindow *lw;
 	SortType type;
 
+	if (!gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(widget))) return;
+
 	lw = submenu_item_get_data(widget);
 	if (!lw) return;
 
@@ -1402,10 +1398,6 @@ void layout_style_set(LayoutWindow *lw, gint style, const gchar *order)
 	lw->info_details = NULL;
 	lw->info_zoom = NULL;
 
-#if 0
-	if (lw->menu_fact) g_object_unref(G_OBJECT(lw->menu_fact));
-	lw->menu_fact = NULL;
-#endif
 	if (lw->ui_manager) g_object_unref(lw->ui_manager);
 	lw->ui_manager = NULL;
 	lw->action_group = NULL;
@@ -1594,9 +1586,6 @@ void layout_free(LayoutWindow *lw)
 
 	layout_bars_close(lw);
 
-#if 0
-	if (lw->menu_fact) g_object_unref(G_OBJECT(lw->menu_fact));
-#endif
 	if (lw->tooltips) g_object_unref(G_OBJECT(lw->tooltips));
 	gtk_widget_destroy(lw->window);
 
@@ -1709,10 +1698,6 @@ LayoutWindow *layout_new(const gchar *path, gint popped, gint hidden)
 
 	layout_keyboard_init(lw, lw->window);
 
-#if 0
-	gtk_widget_realize(lw->window);
-#endif
-
 	lw->tooltips = gtk_tooltips_new();
 
 	/* take ownership of tooltips */
