@@ -75,6 +75,9 @@ struct _ImageLoader
 
 	guint buffer_size;
 
+	gint requested_width;
+	gint requested_height;
+
 	gint done;
 	gint idle_id;
 	gint idle_priority;
@@ -85,7 +88,7 @@ struct _ImageLoader
 	void (*func_area_ready)(ImageLoader *, guint x, guint y, guint w, guint h, gpointer);
 	void (*func_error)(ImageLoader *, gpointer);
 	void (*func_done)(ImageLoader *, gpointer);
-	void (*func_percent)(ImageLoader *, gfloat, gpointer);
+	void (*func_percent)(ImageLoader *, gdouble, gpointer);
 
 	gpointer data_area_ready;
 	gpointer data_error;
@@ -95,25 +98,28 @@ struct _ImageLoader
 	gint idle_done_id;
 };
 
+typedef void (* ThumbLoaderFunc)(ThumbLoader *tl, gpointer data);
+
 struct _ThumbLoader
 {
+	gint standard_loader;
+
 	GdkPixbuf *pixbuf;	/* contains final (scaled) image when done */
 	ImageLoader *il;
 	gchar *path;
 
-	gint from_cache;
-	gfloat percent_done;
+	gint cache_enable;
+	gint cache_hit;
+	gdouble percent_done;
 
 	gint max_w;
 	gint max_h;
 
-	void (*func_error)(ThumbLoader *, gpointer);
-	void (*func_done)(ThumbLoader *, gpointer);
-	void (*func_percent)(ThumbLoader *, gfloat, gpointer);
+	ThumbLoaderFunc func_done;
+	ThumbLoaderFunc func_error;
+	ThumbLoaderFunc func_progress;
 
-	gpointer data_error;
-	gpointer data_done;
-	gpointer data_percent;
+	gpointer data;
 
 	gint idle_done_id;
 };
@@ -207,7 +213,6 @@ struct _CollectWindow
 struct _ImageWindow
 {
 	GtkWidget *widget;	/* use this to add it and show it */
-	GtkWidget *eventbox;
 	GtkWidget *image;
 
 	gchar *image_path;
@@ -235,8 +240,8 @@ struct _ImageWindow
 	gint x_scroll;		/* scroll offset of image (into width, height to start drawing) */
 	gint y_scroll;
 
-	gfloat zoom;		/* zoom we want (0 is auto) */
-	gfloat scale;		/* zoom we got (should never be 0) */
+	gdouble zoom;		/* zoom we want (0 is auto) */
+	gdouble scale;		/* zoom we got (should never be 0) */
 
 	gint tile_width;
 	gint tile_height;
@@ -341,10 +346,10 @@ struct _LayoutWindow
 
 	GtkTooltips *tooltips;
 
-	/* menu, path selector */
+	/* menus, path selector */
 
-	GtkItemFactory *menu_fact;
-	GtkAccelGroup *accel_grp;
+	GtkActionGroup *action_group;
+	GtkUIManager *ui_manager;
 
 	GtkWidget *path_entry;
 
@@ -514,7 +519,7 @@ struct _ViewFileList
 	FileData *thumbs_filedata;
 
 	/* func list */
-	void (*func_thumb_status)(ViewFileList *vfl, gfloat val, const gchar *text, gpointer data);
+	void (*func_thumb_status)(ViewFileList *vfl, gdouble val, const gchar *text, gpointer data);
 	gpointer data_thumb_status;
 
 	void (*func_status)(ViewFileList *vfl, gpointer data);
@@ -568,7 +573,7 @@ struct _ViewFileIcon
 	FileData *thumbs_fd;
 
 	/* func list */
-	void (*func_thumb_status)(ViewFileIcon *vfi, gfloat val, const gchar *text, gpointer data);
+	void (*func_thumb_status)(ViewFileIcon *vfi, gdouble val, const gchar *text, gpointer data);
 	gpointer data_thumb_status;
 
 	void (*func_status)(ViewFileIcon *vfi, gpointer data);
@@ -627,6 +632,7 @@ struct _PixmapFolders
 	GdkPixbuf *close;
 	GdkPixbuf *open;
 	GdkPixbuf *deny;
+	GdkPixbuf *parent;
 };
 
 
