@@ -1,6 +1,6 @@
 /*
  * (SLIK) SimpLIstic sKin functions
- * (C) 2004 John Ellis
+ * (C) 2006 John Ellis
  *
  * Author: John Ellis
  *
@@ -62,7 +62,7 @@ static gint encoding_dialog_idle(gpointer data)
 
 static gint encoding_dialog_delay(gpointer data)
 {
-	gtk_idle_add(encoding_dialog_idle, data);
+	g_idle_add(encoding_dialog_idle, data);
 
 	return 0;
 }
@@ -109,9 +109,13 @@ static void encoding_dialog(const gchar *path)
 		g_free(name);
 		}
 
-	gd = generic_dialog_new("Filename encoding locale mismatch", string->str,
+	gd = generic_dialog_new("Filename encoding locale mismatch",
 				PACKAGE, "locale warning", NULL, TRUE, NULL, NULL);
-	generic_dialog_add_stock(gd, NULL, GTK_STOCK_CLOSE, NULL, TRUE);
+	generic_dialog_add_button(gd, GTK_STOCK_CLOSE, NULL, NULL, TRUE);
+
+	generic_dialog_add_message(gd, GTK_STOCK_DIALOG_WARNING,
+				   "Filename encoding locale mismatch", string->str);
+
 	gtk_widget_show(gd->dialog);
 
 	g_string_free(string, TRUE);
@@ -323,7 +327,7 @@ gint rmdir_utf8(const gchar *s)
 	return ret;
 }
 
-gint copy_file_attributes(const gchar *s, const gchar *t)
+gint copy_file_attributes(const gchar *s, const gchar *t, gint perms, gint mtime)
 {
 	struct stat st;
 	gchar *sl, *tl;
@@ -342,12 +346,12 @@ gint copy_file_attributes(const gchar *s, const gchar *t)
 
 		/* set the dest file attributes to that of source (ignoring errors) */
 
-		if (chown(tl, st.st_uid, st.st_gid) < 0) ret = FALSE;
-		if (chmod(tl, st.st_mode) < 0) ret = FALSE;
+		if (perms && chown(tl, st.st_uid, st.st_gid) < 0) ret = FALSE;
+		if (perms && chmod(tl, st.st_mode) < 0) ret = FALSE;
 
 		tb.actime = st.st_atime;
 		tb.modtime = st.st_mtime;
-		if (utime(tl, &tb) < 0) ret = FALSE;
+		if (mtime && utime(tl, &tb) < 0) ret = FALSE;
 		}
 
 	g_free(sl);
@@ -415,7 +419,7 @@ gint copy_file(const gchar *s, const gchar *t)
 	fclose(fi);
 	fclose(fo);
 
-	copy_file_attributes(s, t);
+	copy_file_attributes(s, t, TRUE, TRUE);
 
 	return TRUE;
 }
@@ -509,36 +513,35 @@ gint path_list(const gchar *path, GList **files, GList **dirs)
 
 	while ((dir = readdir(dp)) != NULL)
 		{
-		/* skip removed files */
-		if (dir->d_ino > 0)
+		gchar *name = dir->d_name;
+		gchar *filepath = g_strconcat(pathl, "/", name, NULL);
+
+		if (stat(filepath, &ent_sbuf) >= 0)
 			{
-			gchar *name = dir->d_name;
-			gchar *filepath = g_strconcat(pathl, "/", name, NULL);
-			if (stat(filepath, &ent_sbuf) >= 0)
+			gchar *path8;
+			gchar *name8;
+
+			name8 = path_to_utf8(name);
+			path8 = g_strconcat(path, "/", name8, NULL);
+			g_free(name8);
+
+			if (dirs && S_ISDIR(ent_sbuf.st_mode) &&
+			    !(name[0] == '.' && (name[1] == '\0' || (name[1] == '.' && name[2] == '\0'))) )
 				{
-				gchar *path8;
-				gchar *name8;
-
-				name8 = path_to_utf8(name);
-				path8 = g_strconcat(path, "/", name8, NULL);
-				g_free(name8);
-
-				if (dirs && S_ISDIR(ent_sbuf.st_mode) &&
-				    !(name[0] == '.' && (name[1] == '\0' || (name[1] == '.' && name[2] == '\0'))) )
-					{
-					d_list = g_list_prepend(d_list, path8);
-					path8 = NULL;
-                       	                }
-                               	else if (files && S_ISREG(ent_sbuf.st_mode))
-					{
-					f_list = g_list_prepend(f_list, path8);
-					path8 = NULL;
-					}
-				g_free(path8);
+				d_list = g_list_prepend(d_list, path8);
+				path8 = NULL;
 				}
-			g_free(filepath);
+			else if (files && S_ISREG(ent_sbuf.st_mode))
+				{
+				f_list = g_list_prepend(f_list, path8);
+				path8 = NULL;
+				}
+			g_free(path8);
 			}
+
+		g_free(filepath);
 		}
+
 	closedir(dp);
 
 	g_free(pathl);
