@@ -613,7 +613,7 @@ GtkWidget *pref_table_box(GtkWidget *table, gint column, gint row,
 		}
 
 	gtk_table_attach(GTK_TABLE(table), shell, column, column + 1, row, row + 1,
-			 GTK_EXPAND | GTK_FILL, FALSE, 0, 0);
+			 GTK_EXPAND | GTK_FILL, 0, 0, 0);
 
 	gtk_widget_show(shell);
 
@@ -628,7 +628,7 @@ GtkWidget *pref_table_label(GtkWidget *table, gint column, gint row,
 
 	align = gtk_alignment_new(alignment, 0.50, 0.0, 0.0);
 	gtk_table_attach(GTK_TABLE(table), align, column, column + 1, row, row + 1,
-			 GTK_FILL, FALSE, 0, 0);
+			 GTK_FILL, 0, 0, 0);
 	gtk_widget_show(align);
 	label = gtk_label_new(text);
 	gtk_container_add(GTK_CONTAINER(align), label);
@@ -645,7 +645,7 @@ GtkWidget *pref_table_button(GtkWidget *table, gint column, gint row,
 
 	button = pref_button_new(NULL, stock_id, text, hide_stock_text, func, data);
 	gtk_table_attach(GTK_TABLE(table), button, column, column + 1, row, row + 1,
-			 GTK_FILL, FALSE, 0, 0);
+			 GTK_FILL, 0, 0, 0);
 	gtk_widget_show(button);
 
 	return button;
