@@ -154,7 +154,8 @@ static gboolean tree_edit_by_path_idle_cb(gpointer data)
 	/* now show it */
 	gtk_widget_set_size_request(ted->window, w, h);
 	gtk_widget_realize(ted->window);
-	gdk_window_move_resize(ted->window->window, x, y, w, h);
+	gtk_window_move(GTK_WINDOW(ted->window), x, y);
+	gtk_window_resize(GTK_WINDOW(ted->window), w, h);
 	gtk_widget_show(ted->window);
 
 	/* grab it */
@@ -532,7 +533,7 @@ void widget_auto_scroll_stop(GtkWidget *widget)
 	if (!sd) return;
 	g_object_set_data(G_OBJECT(widget), "autoscroll", NULL);
 
-	if (sd->timer_id != -1) gtk_timeout_remove(sd->timer_id);
+	if (sd->timer_id != -1) g_source_remove(sd->timer_id);
 	g_free(sd);
 }
 
@@ -614,7 +615,7 @@ gint widget_auto_scroll_start(GtkWidget *widget, GtkAdjustment *v_adj, gint scro
 	sd->adj = v_adj;
 	sd->region_size = region_size;
 	sd->max_step = 1;
-	sd->timer_id = gtk_timeout_add(scroll_speed, widget_auto_scroll_cb, sd);
+	sd->timer_id = g_timeout_add(scroll_speed, widget_auto_scroll_cb, sd);
 
 	sd->notify_func = notify_func;
 	sd->notify_data = notify_data;
